The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {rapsimng.wheat}


Title: Crop-Specific Functions and Parameters for APSIM Next Generation Wheat Model
Version: 0.1.0
Description: Provides wheat-specific functions, processes and parameter sets used by wheat model in the Agricultural Production Systems sIMulator ('APSIM') Next Generation. Includes tools for crop process calculations, parameter management and customisation, enabling users to explore, modify and apply wheat model components.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (≥ 4.1.0)
Imports: optree, tidyweather
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
URL: https://wheat.rapsimng.bangyou.me/, https://github.com/byzheng/rapsimng.wheat
BugReports: https://github.com/byzheng/rapsimng.wheat/issues
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-09-14 05:16:34 UTC; zhe00a
Author: Bangyou Zheng [aut, cre]
Maintainer: Bangyou Zheng <zheng.bangyou@gmail.com>
Repository: CRAN
Date/Publication: 2026-09-24 05:00:02 UTC

Calculate thermal time using cardinal temperatures

Description

Calculate thermal time using cardinal temperatures

Usage

thermal_time(
  mint,
  maxt,
  x_temp = wheat$get("phenology.thermal_time.x"),
  y_temp = wheat$get("phenology.thermal_time.y"),
  method = wheat$get("phenology.thermal_time.method")
)

Arguments

mint

The minimum temperature

maxt

The maximum temperature

x_temp

The cardinal temperatures using to calculate thermal time. The default values are c(0, 26, 37) defined in wheat$get("phenology.thermal_time.x").

y_temp

The effective thermal time at the corresponding cardinal temperatures. The default values are c(0, 26, 0) defined in wheat$get("phenology.thermal_time.y").

method

The method to calculate thermal time. The default method is "3hr", which uses the three hour temperature method. The other option is "default", which uses the default method ( maxt + mint ) / 2 - base.

Details

The daily thermal time is calculated by interpolating the effective thermal time at three hour intervals between the daily minimum and maximum temperatures, and then averaging these values to get the daily thermal time. For more information about the wheat phenology model, see the APSIM Next Generation Wheat Documentation.

Value

The thermal time.

Examples

mint <- c(0, 10)
maxt <- c(30, 40)
thermal_time(mint, maxt)

Wheat model options manager

Description

An options manager for configuring wheat model parameters. This object provides methods to get and set wheat related parameters.

Usage

wheat

Value

An option manager object for configuring wheat model parameters.

Available Options

phenology.thermal_time.x

Cardinal temperatures for thermal time calculation. Default: c(0, 26, 37)

phenology.thermal_time.y

Effective thermal time at corresponding cardinal temperatures. Default: c(0, 26, 0)

phenology.thermal_time.method

Method used for thermal time calculation. Supported values: "3hr" and "HourlySinPpAdjusted". Default: "3hr"

Methods

get(key)

Retrieve the value of an option by its key (e.g., "phenology.thermal_time.x")

set(key, value)

Set the value of an option by its key

reset()

Reset all options to their default values

Examples

# Get default thermal time cardinal temperatures
wheat$get("phenology.thermal_time.x")

# Set custom values
wheat$set("phenology.thermal_time.x" = c(0, 26, 37))
wheat$set("phenology.thermal_time.y" = c(0, 26, 0))

# Reset to defaults
wheat$reset()

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.